{ config, pkgs, lib, ... }:
{
  services.xserver = {
    enable = true;
    displayManager.lightdm = {
      enable = true;
    };
    xkb = {
      # options = "ctrl:nocaps";
      options = "nodeakeys";
      variant = "altgr-intl";
      layout = "us";
    };
    windowManager.qtile.enable = true;
  };

  programs.hyprland.enable = true;

  hardware.keyboard.zsa.enable = true;
  environment.sessionVariables = {
    NIXOS_OZONE_WL = "1";
    SSH_AUTH_SOCK = "/run/user/${toString config.users.users.felixalb.uid}/keyring/ssh";
  };

  home-manager.users.felixalb = {
    services = {
      dunst.enable = true;
    };
    home.packages = with pkgs; [
      i3lock
      libnotify
      pamixer
      pavucontrol
      picom
      sxhkd
      xclip
      xss-lock
    ];

    programs.alacritty.settings = {
      font.size = lib.mkForce 11;
    };
  };

  services.gnome.gnome-keyring.enable = true;

  hardware.opengl.enable = true;

  # Audio
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    pulse.enable = true;
    jack.enable = true;
  };
  hardware.pulseaudio.enable = false;

  # Fonts
  fonts = {
    fontDir.enable = true;
    packages = with pkgs; [
      noto-fonts
      noto-fonts-emoji
      noto-fonts-cjk-sans
      font-awesome
      fira-code
      hack-font
      (nerdfonts.override {
        fonts = [
          "Hack"
        ];
      })
    ];
  };

  # # Dark mode
  # home-manager.users.felixalb = {
  #   dconf.settings = {
  #     "org/gnome/desktop/interface" = {
  #       color-scheme = "prefer-dark";
  #     };
  #   };

  #   gtk = {
  #     enable = true;
  #     theme = {
  #       name = "Adwaita-dark";
  #       package = pkgs.gnome.gnome-themes-extra;
  #     };
  #   };
  # };

  # qt = {
  #   enable = true;
  #   platformTheme = "gnome";
  #   style = "adwaita-dark";
  # };

  # Misc:
  xdg.portal = {
    enable = true;
    wlr.enable = true;
  };
  location.provider = "geoclue2";
  security.polkit.enable = true;
  services.dbus.packages = [ pkgs.gcr ];
  services.openssh.settings.X11Forwarding = true;
}
