{ pkgs, lib, ... }:

{
  imports = [
    ./../../home/base.nix
    ./../../home/alacritty.nix
  ];

  home.packages = with pkgs; [
    bc
    catimg
    chromium
    dante
    dig
    element-desktop
    hunspellDicts.en_US
    hunspellDicts.nb_NO
    jq
    libreoffice
    mpv
    nixpkgs-2211.remmina
    openssl
    pwgen
    unstable.tlclient
    traceroute
    virt-manager
    w3m

    (unstable.python311.withPackages (ps: with ps; [
      numpy
      pycryptodome
      requests
    ]))
  ];

  programs = {
    aerc = {
      enable = true;
      package = pkgs.unstable.aerc;
    };
    alacritty.enable = true;
    firefox.enable = true;
    rbw = {
      enable = true;
      settings = {
        base_url = "https://pw.feal.no";
        email = "felix@albrigtsen.it";
        pinentry = pkgs.pinentry-gnome3;
      };
    };
    rofi = {
      enable = true;
      theme = "iggy";
    };
    zsh = {
      shellAliases."rebuild" = "sudo nixos-rebuild switch --flake /config";
      prezto.pmodules = [ "ssh" ];
    };

    neovim.plugins = with pkgs.vimPlugins; [ copilot-vim ];
  };

  xdg.mimeApps = {
    enable = true;

    defaultApplications = {
      "text/html" = "firefox.desktop";
      "x-scheme-handler/http" = "firefox.desktop";
      "x-scheme-handler/https" = "firefox.desktop";
      "x-scheme-handler/about" = "firefox.desktop";
      "x-scheme-handler/unknown" = "firefox.desktop";
    };
  };

  home.stateVersion = "24.11";
}
